# String Locator

A simple code to find the file containing a given string inside a given path.

At times in the programming world, we might need to change a certain code but don't know which file it is in. The string locator helps the user find the desired file by entering the text and the path to the folder containing all the documents.

## Usage

input:- text,path
return:- a list containing the paths of files that has the given string